
% This script illustrates Theorem 1.1(ii) from the paper
% "On compactly supported dual windows of Gabor frames".
% Theorem 1.1(ii) gives a characterization of 
% all compactly supported real-valued dual windows (when such ones exist)
% of a Gabor frame with a real-valued compactly supported generating window.
% For the Gabor frame and its dual frame in Example 2.4,
% this script determines a new real valued compactly suppored dual window 
% based on the formula (2) in Theorem 1.1(ii).
% Some of the outputs of this script produce the graphics in Fig.1(a)(b) in the paper,
% they concern the case with lambda=1/10. 
% In order to produce Fig.1(c)(d), 
% one should replace the line "lambda=1/10;" from the script with "lambda=1/2;".

function f=dualwindowFig1()

% Author:
% Diana Stoeva, dtstoeva@kfs.oeaw.ac.at
% created May 2020, final version Feb 2021
%
% This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License.
% To view a copy of this license, visit 
% http://creativecommons.org/licenses/by-nc-sa/3.0/
% and
% https://creativecommons.org/licenses/by-nc-sa/3.0/legalcode

clear;
x=sym('x');

assume(x,'real');

%% input 

% the generating window g
g=B2; % for this line the function B2.m is used

% the initial dual window gd
gd=h2; % for this line the function h2.m is used
%the support of h2 is [-1,3] 
supportgdmin=-1;
supportgdmax=3;

a=1;
b=1/3;

%the bounds of the interval for the graphics
leftboundint=-3;
rightboundint=5;

%the sum on k is on the set K which depends on g,gd,a 
%for the chosen g and gd as above, we have K={-2,-1,0,1,2}
kmin=-2; 
kmax=2;

% the function w 
lambda=1/10; 
% lambda=1/2
w=lambda.*g;
 
 % needed for the file-names when saving the plots, to distinguish which lambda-version of the program runs
 if lambda==1/2 
         denom=2;
 else denom=10;
 end

% The sum on j in formula (2) in the paper is truncated til j=jmax. 
% Here jmax is taken to be 7 
% (the window computed with sum on j truncated til j=6 
% and the window computed with sum on j truncated til j=7 
% are very close to each other)
jmax=7;

%% Main part of the program

j=0
S0=0;

for k=[kmin:kmax]
   Tkaw=subs(w, x, x-k*a); %translirane na w s ka-edinitsi, i.e. T_(ka)w
   S0=simplify(S0+integral0k(k).*Tkaw);
   %S0=S0+integral0k(k).*Tkaw;
end

gdualnewj=gd+w-S0;



for j=[1:jmax]
     j
     summandj=0;
   
   for k=[kmin:kmax]
    Tkaw=subs(w, x, x-k*a); %translirane na w s ka-edinitsi, i.e. T_(ka)w
    summandj=simplify(summandj+(integralcosjk(j,k) + integralsinjk(j,k)).*Tkaw);
    %summandj=summandj+(integralcosjk(j,k) + integralsinjk(j,k)).*Tkaw;
   end
   
   gdualnewjnext=gdualnewj-2*summandj;
   
   % plot of gdualnewj and gdualnewjnext, to compare the graphics for two neigbour values of j 
   figure(j)
   fplot(gdualnewj,[leftboundint,rightboundint],'b--*')
   hold on
   fplot(gdualnewjnext,[leftboundint,rightboundint],'r')
   hold off
   grid on
      
   %This is in order to save all the figures in the loop
   baseFileName = sprintf('fig1_lambda1over%d_real_compact_dual_window_%d', denom, j) 
   savefig(baseFileName);
   saveas(gcf, baseFileName, 'png' );  
   
   gdualnewj=gdualnewjnext;

 end
 
figure(jmax+1)
fplot(g,[leftboundint,rightboundint], 'g') % green % red colour
hold on
fplot(gd,[leftboundint,rightboundint], 'b--') % blue % green colour
hold on
fplot(gdualnewj,[leftboundint,rightboundint], 'r') %'r--') % red % blue colour
hold off
grid on

%To save the figure
baseFileName = sprintf('fig1_lambda1over%d_real_compact_dual_window_%d', denom, jmax+1) 
savefig(baseFileName)
saveas(gcf, baseFileName, 'png' );
  
  

%% Needed functions 

function f = integralcosjk(j,k)
assume(x,'real');
alphajx=2*pi*j*b*x;
Tkag=subs(g, x, x-k*a); %translirane na g s ka-edinitsi, i.e. T_(ka)g
% .* is used for pointwise multiplication of functions
f=int(gd.*cos(alphajx).*Tkag, supportgdmin, supportgdmax); 
f=f.*cos(alphajx);
end

function f = integralsinjk(j,k)
assume(x,'real');
alphajx=2*pi*j*b*x;
Tkag=subs(g, x, x-k*a); %translirane na g s ka-edinitsi, i.e. T_(ka)g
% .* is used for pointwise multiplication of functions
f=int(gd.*sin(alphajx).*Tkag, supportgdmin, supportgdmax);
f=f.*sin(alphajx);
end

function f = integral0k(k)
assume(x,'real');
Tkag=subs(g, x, x-k*a); %translirane na g s ka-edinitsi, i.e. T_(ka)g
f=int(gd.*(Tkag), supportgdmin, supportgdmax); 
end

end